diff --git a/.gitignore b/.gitignore
index 84faae1806..61a3b53de1 100644
--- a/.gitignore
+++ b/.gitignore
@@ -215,3 +215,4 @@ src/Web/Avalonia.Web.Blazor/Interop/Typescript/*.js
node_modules
src/Web/Avalonia.Web.Blazor/webapp/package-lock.json
src/Web/Avalonia.Web.Blazor/wwwroot
+src/Web/Avalonia.Web/wwwroot
diff --git a/.gitmodules b/.gitmodules
index 2d11fdfa9e..032bc879cc 100644
--- a/.gitmodules
+++ b/.gitmodules
@@ -4,3 +4,6 @@
[submodule "src/Markup/Avalonia.Markup.Xaml/XamlIl/xamlil.github"]
path = src/Markup/Avalonia.Markup.Xaml.Loader/xamlil.github
url = https://github.com/kekekeks/XamlX.git
+[submodule "nukebuild/il-repack"]
+ path = nukebuild/il-repack
+ url = https://github.com/Gillibald/il-repack
diff --git a/.nuke b/.nuke
deleted file mode 100644
index e69de29bb2..0000000000
diff --git a/.nuke/build.schema.json b/.nuke/build.schema.json
new file mode 100644
index 0000000000..5bbc3d6915
--- /dev/null
+++ b/.nuke/build.schema.json
@@ -0,0 +1,148 @@
+{
+ "$schema": "http://json-schema.org/draft-04/schema#",
+ "title": "Build Schema",
+ "$ref": "#/definitions/build",
+ "definitions": {
+ "build": {
+ "type": "object",
+ "properties": {
+ "Configuration": {
+ "type": "string",
+ "description": "configuration"
+ },
+ "Continue": {
+ "type": "boolean",
+ "description": "Indicates to continue a previously failed build attempt"
+ },
+ "ForceNugetVersion": {
+ "type": "string",
+ "description": "force-nuget-version"
+ },
+ "Help": {
+ "type": "boolean",
+ "description": "Shows the help text for this build assembly"
+ },
+ "Host": {
+ "type": "string",
+ "description": "Host for execution. Default is 'automatic'",
+ "enum": [
+ "AppVeyor",
+ "AzurePipelines",
+ "Bamboo",
+ "Bitbucket",
+ "Bitrise",
+ "GitHubActions",
+ "GitLab",
+ "Jenkins",
+ "Rider",
+ "SpaceAutomation",
+ "TeamCity",
+ "Terminal",
+ "TravisCI",
+ "VisualStudio",
+ "VSCode"
+ ]
+ },
+ "NoLogo": {
+ "type": "boolean",
+ "description": "Disables displaying the NUKE logo"
+ },
+ "Partition": {
+ "type": "string",
+ "description": "Partition to use on CI"
+ },
+ "Plan": {
+ "type": "boolean",
+ "description": "Shows the execution plan (HTML)"
+ },
+ "Profile": {
+ "type": "array",
+ "description": "Defines the profiles to load",
+ "items": {
+ "type": "string"
+ }
+ },
+ "Root": {
+ "type": "string",
+ "description": "Root directory during build execution"
+ },
+ "Skip": {
+ "type": "array",
+ "description": "List of targets to be skipped. Empty list skips all dependencies",
+ "items": {
+ "type": "string",
+ "enum": [
+ "CiAzureLinux",
+ "CiAzureOSX",
+ "CiAzureWindows",
+ "Clean",
+ "Compile",
+ "CompileHtmlPreviewer",
+ "CompileNative",
+ "CreateIntermediateNugetPackages",
+ "CreateNugetPackages",
+ "GenerateCppHeaders",
+ "Package",
+ "RunCoreLibsTests",
+ "RunDesignerTests",
+ "RunHtmlPreviewerTests",
+ "RunLeakTests",
+ "RunRenderTests",
+ "RunTests",
+ "ZipFiles"
+ ]
+ }
+ },
+ "SkipPreviewer": {
+ "type": "boolean",
+ "description": "skip-previewer"
+ },
+ "SkipTests": {
+ "type": "boolean",
+ "description": "skip-tests"
+ },
+ "Solution": {
+ "type": "string",
+ "description": "Path to a solution file that is automatically loaded. Default is Avalonia.sln"
+ },
+ "Target": {
+ "type": "array",
+ "description": "List of targets to be invoked. Default is '{default_target}'",
+ "items": {
+ "type": "string",
+ "enum": [
+ "CiAzureLinux",
+ "CiAzureOSX",
+ "CiAzureWindows",
+ "Clean",
+ "Compile",
+ "CompileHtmlPreviewer",
+ "CompileNative",
+ "CreateIntermediateNugetPackages",
+ "CreateNugetPackages",
+ "GenerateCppHeaders",
+ "Package",
+ "RunCoreLibsTests",
+ "RunDesignerTests",
+ "RunHtmlPreviewerTests",
+ "RunLeakTests",
+ "RunRenderTests",
+ "RunTests",
+ "ZipFiles"
+ ]
+ }
+ },
+ "Verbosity": {
+ "type": "string",
+ "description": "Logging verbosity during build execution. Default is 'Normal'",
+ "enum": [
+ "Minimal",
+ "Normal",
+ "Quiet",
+ "Verbose"
+ ]
+ }
+ }
+ }
+ }
+}
\ No newline at end of file
diff --git a/.nuke/parameters.json b/.nuke/parameters.json
new file mode 100644
index 0000000000..42521bb7dd
--- /dev/null
+++ b/.nuke/parameters.json
@@ -0,0 +1,4 @@
+{
+ "$schema": "./build.schema.json",
+ "Solution": ""
+}
\ No newline at end of file
diff --git a/Avalonia.sln b/Avalonia.sln
index 68335c672c..81a9b43890 100644
--- a/Avalonia.sln
+++ b/Avalonia.sln
@@ -212,7 +212,11 @@ Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Avalonia.Controls.ColorPick
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Avalonia.DesignerSupport.Tests", "tests\Avalonia.DesignerSupport.Tests\Avalonia.DesignerSupport.Tests.csproj", "{EABE2161-989B-42BF-BD8D-1E34B20C21F1}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "DevGenerators", "src\tools\DevGenerators\DevGenerators.csproj", "{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB}"
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "DevGenerators", "src\tools\DevGenerators\DevGenerators.csproj", "{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB}"
+EndProject
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Avalonia.Web", "src\Web\Avalonia.Web\Avalonia.Web.csproj", "{76D39FF6-6B4F-46C4-93CD-E6FC4665739E}"
+EndProject
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Avalonia.Web.Sample", "src\Web\Avalonia.Web.Sample\Avalonia.Web.Sample.csproj", "{1F61B6F1-B881-4E27-A5B0-09D1F543F7AC}"
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "MobileSandbox", "samples\MobileSandbox\MobileSandbox.csproj", "{3B8519C1-2F51-4F12-A348-120AB91D4532}"
EndProject
@@ -407,9 +411,7 @@ Global
{BF28998D-072C-439A-AFBB-2FE5021241E0}.Release|Any CPU.ActiveCfg = Release|Any CPU
{BF28998D-072C-439A-AFBB-2FE5021241E0}.Release|Any CPU.Build.0 = Release|Any CPU
{3F00BC43-5095-477F-93D8-E65B08179A00}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
- {3F00BC43-5095-477F-93D8-E65B08179A00}.Debug|Any CPU.Build.0 = Debug|Any CPU
{3F00BC43-5095-477F-93D8-E65B08179A00}.Release|Any CPU.ActiveCfg = Release|Any CPU
- {3F00BC43-5095-477F-93D8-E65B08179A00}.Release|Any CPU.Build.0 = Release|Any CPU
{41B02319-965D-4945-8005-C1A3D1224165}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
{41B02319-965D-4945-8005-C1A3D1224165}.Debug|Any CPU.Build.0 = Debug|Any CPU
{41B02319-965D-4945-8005-C1A3D1224165}.Release|Any CPU.ActiveCfg = Release|Any CPU
@@ -510,6 +512,14 @@ Global
{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB}.Debug|Any CPU.Build.0 = Debug|Any CPU
{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB}.Release|Any CPU.ActiveCfg = Release|Any CPU
{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB}.Release|Any CPU.Build.0 = Release|Any CPU
+ {76D39FF6-6B4F-46C4-93CD-E6FC4665739E}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {76D39FF6-6B4F-46C4-93CD-E6FC4665739E}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {76D39FF6-6B4F-46C4-93CD-E6FC4665739E}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {76D39FF6-6B4F-46C4-93CD-E6FC4665739E}.Release|Any CPU.Build.0 = Release|Any CPU
+ {1F61B6F1-B881-4E27-A5B0-09D1F543F7AC}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {1F61B6F1-B881-4E27-A5B0-09D1F543F7AC}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {1F61B6F1-B881-4E27-A5B0-09D1F543F7AC}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {1F61B6F1-B881-4E27-A5B0-09D1F543F7AC}.Release|Any CPU.Build.0 = Release|Any CPU
{3B8519C1-2F51-4F12-A348-120AB91D4532}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
{3B8519C1-2F51-4F12-A348-120AB91D4532}.Debug|Any CPU.Build.0 = Debug|Any CPU
{3B8519C1-2F51-4F12-A348-120AB91D4532}.Release|Any CPU.ActiveCfg = Release|Any CPU
@@ -583,6 +593,8 @@ Global
{2B390431-288C-435C-BB6B-A374033BD8D1} = {4ED8B739-6F4E-4CD4-B993-545E6B5CE637}
{EABE2161-989B-42BF-BD8D-1E34B20C21F1} = {C5A00AC3-B34C-4564-9BDD-2DA473EF4D8B}
{1BBFAD42-B99E-47E0-B00A-A4BC6B6BB4BB} = {4ED8B739-6F4E-4CD4-B993-545E6B5CE637}
+ {76D39FF6-6B4F-46C4-93CD-E6FC4665739E} = {86A3F706-DC3C-43C6-BE1B-B98F5BAAA268}
+ {1F61B6F1-B881-4E27-A5B0-09D1F543F7AC} = {86A3F706-DC3C-43C6-BE1B-B98F5BAAA268}
{4D36CEC8-53F2-40A5-9A37-79AAE356E2DA} = {86C53C40-57AA-45B8-AD42-FAE0EFDF0F2B}
{3B8519C1-2F51-4F12-A348-120AB91D4532} = {9B9E3891-2366-4253-A952-D08BCEB71098}
{C90FE60B-B01E-4F35-91D6-379D6966030F} = {9B9E3891-2366-4253-A952-D08BCEB71098}
diff --git a/azure-pipelines-integrationtests.yml b/azure-pipelines-integrationtests.yml
index 0b79758c76..ee8abb75c1 100644
--- a/azure-pipelines-integrationtests.yml
+++ b/azure-pipelines-integrationtests.yml
@@ -41,9 +41,9 @@ jobs:
steps:
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 6.0.202'
+ displayName: 'Use .NET Core SDK 6.0.401'
inputs:
- version: 6.0.202
+ version: 6.0.401
- task: Windows Application Driver@0
inputs:
@@ -57,6 +57,7 @@ jobs:
projects: 'samples/IntegrationTestApp/IntegrationTestApp.csproj'
- task: DotNetCoreCLI@2
+ retryCountOnTaskFailure: 3
inputs:
command: 'test'
projects: 'tests/Avalonia.IntegrationTests.Appium/Avalonia.IntegrationTests.Appium.csproj'
diff --git a/azure-pipelines.yml b/azure-pipelines.yml
index 52fc8db53c..33b2dc670a 100644
--- a/azure-pipelines.yml
+++ b/azure-pipelines.yml
@@ -6,7 +6,6 @@ jobs:
variables:
SolutionDir: '$(Build.SourcesDirectory)'
steps:
-
- task: PowerShell@2
displayName: Get PR Number
inputs:
@@ -31,14 +30,20 @@ jobs:
vmImage: 'ubuntu-20.04'
steps:
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 3.1.418'
+ displayName: 'Use .NET Core SDK 6.0.401'
inputs:
- version: 3.1.418
+ version: 6.0.401
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 6.0.202'
+ displayName: 'Use .NET Core SDK 7.0.100-rc.1.22431.12'
+ inputs:
+ version: 7.0.100-rc.1.22431.12
+
+ - task: CmdLine@2
+ displayName: 'Install Workloads'
inputs:
- version: 6.0.202
+ script: |
+ dotnet workload install wasm-tools wasm-experimental
- task: CmdLine@2
displayName: 'Run Build'
@@ -62,22 +67,21 @@ jobs:
vmImage: 'macos-12'
steps:
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 3.1.418'
+ displayName: 'Use .NET Core SDK 6.0.401'
inputs:
- version: 3.1.418
+ version: 6.0.401
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 6.0.202'
+ displayName: 'Use .NET Core SDK 7.0.100-rc.1.22431.12'
inputs:
- version: 6.0.202
-
+ version: 7.0.100-rc.1.22431.12
+
- task: CmdLine@2
- displayName: 'Install Mono 5.18'
+ displayName: 'Install Workloads'
inputs:
script: |
- curl -o ./mono.pkg https://download.mono-project.com/archive/5.18.0/macos-10-universal/MonoFramework-MDK-5.18.0.225.macos10.xamarin.universal.pkg
- sudo installer -verbose -pkg ./mono.pkg -target /
-
+ dotnet workload install wasm-tools wasm-experimental
+
- task: CmdLine@2
displayName: 'Generate avalonia-native'
inputs:
@@ -134,26 +138,26 @@ jobs:
SolutionDir: '$(Build.SourcesDirectory)'
steps:
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 3.1.418'
+ displayName: 'Use .NET Core SDK 6.0.401'
inputs:
- version: 3.1.418
+ version: 6.0.401
- task: UseDotNet@2
- displayName: 'Use .NET Core SDK 6.0.202'
+ displayName: 'Use .NET Core SDK 7.0.100-rc.1.22431.12'
inputs:
- version: 6.0.202
+ version: 7.0.100-rc.1.22431.12
- task: CmdLine@2
displayName: 'Install Workloads'
inputs:
script: |
- dotnet workload install android ios
+ dotnet workload install android ios wasm-tools wasm-experimental
- task: CmdLine@2
displayName: 'Install Nuke'
inputs:
script: |
- dotnet tool install --global Nuke.GlobalTool --version 0.24.0
+ dotnet tool install --global Nuke.GlobalTool --version 6.2.1
- task: CmdLine@2
displayName: 'Run Nuke'
diff --git a/build.cmd b/build.cmd
new file mode 100644
index 0000000000..b08cc590f4
--- /dev/null
+++ b/build.cmd
@@ -0,0 +1,7 @@
+:; set -eo pipefail
+:; SCRIPT_DIR=$(cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd)
+:; ${SCRIPT_DIR}/build.sh "$@"
+:; exit $?
+
+@ECHO OFF
+powershell -ExecutionPolicy ByPass -NoProfile -File "%~dp0build.ps1" %*
diff --git a/build.ps1 b/build.ps1
index 985e8abcee..997e5b423f 100644
--- a/build.ps1
+++ b/build.ps1
@@ -1,13 +1,12 @@
[CmdletBinding()]
Param(
- #[switch]$CustomParam,
[Parameter(Position=0,Mandatory=$false,ValueFromRemainingArguments=$true)]
[string[]]$BuildArguments
)
-Write-Output "Windows PowerShell $($Host.Version)"
+Write-Output "PowerShell $($PSVersionTable.PSEdition) version $($PSVersionTable.PSVersion)"
-Set-StrictMode -Version 2.0; $ErrorActionPreference = "Stop"; $ConfirmPreference = "None"; trap { exit 1 }
+Set-StrictMode -Version 2.0; $ErrorActionPreference = "Stop"; $ConfirmPreference = "None"; trap { Write-Error $_ -ErrorAction Continue; exit 1 }
$PSScriptRoot = Split-Path $MyInvocation.MyCommand.Path -Parent
###########################################################################
@@ -15,15 +14,15 @@ $PSScriptRoot = Split-Path $MyInvocation.MyCommand.Path -Parent
###########################################################################
$BuildProjectFile = "$PSScriptRoot\nukebuild\_build.csproj"
-$TempDirectory = "$PSScriptRoot\\.tmp"
+$TempDirectory = "$PSScriptRoot\\.nuke\temp"
$DotNetGlobalFile = "$PSScriptRoot\\global.json"
-$DotNetInstallUrl = "https://raw.githubusercontent.com/dotnet/cli/master/scripts/obtain/dotnet-install.ps1"
+$DotNetInstallUrl = "https://dot.net/v1/dotnet-install.ps1"
$DotNetChannel = "Current"
$env:DOTNET_SKIP_FIRST_TIME_EXPERIENCE = 1
$env:DOTNET_CLI_TELEMETRY_OPTOUT = 1
-$env:NUGET_XMLDOC_MODE = "skip"
+$env:DOTNET_MULTILEVEL_LOOKUP = 0
###########################################################################
# EXECUTION
@@ -34,38 +33,37 @@ function ExecSafe([scriptblock] $cmd) {
if ($LASTEXITCODE) { exit $LASTEXITCODE }
}
-# If global.json exists, load expected version
-if (Test-Path $DotNetGlobalFile) {
- $DotNetGlobal = $(Get-Content $DotNetGlobalFile | Out-String | ConvertFrom-Json)
- if ($DotNetGlobal.PSObject.Properties["sdk"] -and $DotNetGlobal.sdk.PSObject.Properties["version"]) {
- $DotNetVersion = $DotNetGlobal.sdk.version
- }
-}
-
-# If dotnet is installed locally, and expected version is not set or installation matches the expected version
+# If dotnet CLI is installed globally and it matches requested version, use for execution
if ($null -ne (Get-Command "dotnet" -ErrorAction SilentlyContinue) -and `
- (!(Test-Path variable:DotNetVersion) -or $(& dotnet --version) -eq $DotNetVersion)) {
+ $(dotnet --version) -and $LASTEXITCODE -eq 0) {
$env:DOTNET_EXE = (Get-Command "dotnet").Path
}
else {
- $DotNetDirectory = "$TempDirectory\dotnet-win"
- $env:DOTNET_EXE = "$DotNetDirectory\dotnet.exe"
-
# Download install script
$DotNetInstallFile = "$TempDirectory\dotnet-install.ps1"
- mkdir -force $TempDirectory > $null
+ New-Item -ItemType Directory -Path $TempDirectory -Force | Out-Null
+ [Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12
(New-Object System.Net.WebClient).DownloadFile($DotNetInstallUrl, $DotNetInstallFile)
+ # If global.json exists, load expected version
+ if (Test-Path $DotNetGlobalFile) {
+ $DotNetGlobal = $(Get-Content $DotNetGlobalFile | Out-String | ConvertFrom-Json)
+ if ($DotNetGlobal.PSObject.Properties["sdk"] -and $DotNetGlobal.sdk.PSObject.Properties["version"]) {
+ $DotNetVersion = $DotNetGlobal.sdk.version
+ }
+ }
+
# Install by channel or version
+ $DotNetDirectory = "$TempDirectory\dotnet-win"
if (!(Test-Path variable:DotNetVersion)) {
- ExecSafe { & $DotNetInstallFile -InstallDir $DotNetDirectory -Channel $DotNetChannel -NoPath }
+ ExecSafe { & powershell $DotNetInstallFile -InstallDir $DotNetDirectory -Channel $DotNetChannel -NoPath }
} else {
- ExecSafe { & $DotNetInstallFile -InstallDir $DotNetDirectory -Version $DotNetVersion -NoPath }
+ ExecSafe { & powershell $DotNetInstallFile -InstallDir $DotNetDirectory -Version $DotNetVersion -NoPath }
}
-
- $env:PATH="$DotNetDirectory;$env:PATH"
+ $env:DOTNET_EXE = "$DotNetDirectory\dotnet.exe"
}
-Write-Output "Microsoft (R) .NET Core SDK version $(& $env:DOTNET_EXE --version)"
+Write-Output "Microsoft (R) .NET SDK version $(& $env:DOTNET_EXE --version)"
-ExecSafe { & $env:DOTNET_EXE run --project $BuildProjectFile -- $BuildArguments }
+ExecSafe { & $env:DOTNET_EXE build $BuildProjectFile /nodeReuse:false /p:UseSharedCompilation=false -nologo -clp:NoSummary --verbosity quiet }
+ExecSafe { & $env:DOTNET_EXE run --project $BuildProjectFile --no-build -- $BuildArguments }
diff --git a/build.sh b/build.sh
index 9532b4fbe0..76919a5351 100755
--- a/build.sh
+++ b/build.sh
@@ -1,16 +1,6 @@
#!/usr/bin/env bash
-echo $(bash --version 2>&1 | head -n 1)
-
-#CUSTOMPARAM=0
-BUILD_ARGUMENTS=()
-for i in "$@"; do
- case $(echo $1 | awk '{print tolower($0)}') in
- # -custom-param) CUSTOMPARAM=1;;
- *) BUILD_ARGUMENTS+=("$1") ;;
- esac
- shift
-done
+bash --version 2>&1 | head -n 1
set -eo pipefail
SCRIPT_DIR=$(cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd)
@@ -20,11 +10,53 @@ SCRIPT_DIR=$(cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd)
###########################################################################
BUILD_PROJECT_FILE="$SCRIPT_DIR/nukebuild/_build.csproj"
+TEMP_DIRECTORY="$SCRIPT_DIR//.nuke/temp"
+
+DOTNET_GLOBAL_FILE="$SCRIPT_DIR//global.json"
+DOTNET_INSTALL_URL="https://dot.net/v1/dotnet-install.sh"
+DOTNET_CHANNEL="Current"
export DOTNET_CLI_TELEMETRY_OPTOUT=1
export DOTNET_SKIP_FIRST_TIME_EXPERIENCE=1
-export NUGET_XMLDOC_MODE="skip"
+export DOTNET_MULTILEVEL_LOOKUP=0
-dotnet --info
+###########################################################################
+# EXECUTION
+###########################################################################
-dotnet run --project "$BUILD_PROJECT_FILE" -- ${BUILD_ARGUMENTS[@]}
+function FirstJsonValue {
+ perl -nle 'print $1 if m{"'"$1"'": "([^"]+)",?}' <<< "${@:2}"
+}
+
+# If dotnet CLI is installed globally and it matches requested version, use for execution
+if [ -x "$(command -v dotnet)" ] && dotnet --version &>/dev/null; then
+ export DOTNET_EXE="$(command -v dotnet)"
+else
+ # Download install script
+ DOTNET_INSTALL_FILE="$TEMP_DIRECTORY/dotnet-install.sh"
+ mkdir -p "$TEMP_DIRECTORY"
+ curl -Lsfo "$DOTNET_INSTALL_FILE" "$DOTNET_INSTALL_URL"
+ chmod +x "$DOTNET_INSTALL_FILE"
+
+ # If global.json exists, load expected version
+ if [[ -f "$DOTNET_GLOBAL_FILE" ]]; then
+ DOTNET_VERSION=$(FirstJsonValue "version" "$(cat "$DOTNET_GLOBAL_FILE")")
+ if [[ "$DOTNET_VERSION" == "" ]]; then
+ unset DOTNET_VERSION
+ fi
+ fi
+
+ # Install by channel or version
+ DOTNET_DIRECTORY="$TEMP_DIRECTORY/dotnet-unix"
+ if [[ -z ${DOTNET_VERSION+x} ]]; then
+ "$DOTNET_INSTALL_FILE" --install-dir "$DOTNET_DIRECTORY" --channel "$DOTNET_CHANNEL" --no-path
+ else
+ "$DOTNET_INSTALL_FILE" --install-dir "$DOTNET_DIRECTORY" --version "$DOTNET_VERSION" --no-path
+ fi
+ export DOTNET_EXE="$DOTNET_DIRECTORY/dotnet"
+fi
+
+echo "Microsoft (R) .NET SDK version $("$DOTNET_EXE" --version)"
+
+"$DOTNET_EXE" build "$BUILD_PROJECT_FILE" /nodeReuse:false /p:UseSharedCompilation=false -nologo -clp:NoSummary --verbosity quiet
+"$DOTNET_EXE" run --project "$BUILD_PROJECT_FILE" --no-build -- "$@"
diff --git a/dirs.proj b/dirs.proj
index 47ad0dfd55..a2544ef951 100644
--- a/dirs.proj
+++ b/dirs.proj
@@ -23,12 +23,13 @@
+
-
+
diff --git a/global.json b/global.json
index a6792b05c7..44d4e10dbf 100644
--- a/global.json
+++ b/global.json
@@ -1,8 +1,4 @@
{
- "sdk": {
- "version": "6.0.202",
- "rollForward": "latestFeature"
- },
"msbuild-sdks": {
"Microsoft.Build.Traversal": "1.0.43",
"MSBuild.Sdk.Extras": "3.0.22",
diff --git a/nukebuild/Build.cs b/nukebuild/Build.cs
index 4bbb667154..7425c344c3 100644
--- a/nukebuild/Build.cs
+++ b/nukebuild/Build.cs
@@ -23,6 +23,7 @@ using static Nuke.Common.Tools.MSBuild.MSBuildTasks;
using static Nuke.Common.Tools.DotNet.DotNetTasks;
using static Nuke.Common.Tools.Xunit.XunitTasks;
using static Nuke.Common.Tools.VSWhere.VSWhereTasks;
+using MicroCom.CodeGenerator;
/*
Before editing this file, install support plugin for your IDE,
@@ -163,7 +164,7 @@ partial class Build : NukeBuild
.EnableNoBuild()
.EnableNoRestore()
.When(Parameters.PublishTestResults, _ => _
- .SetLogger("trx")
+ .SetLoggers("trx")
.SetResultsDirectory(Parameters.TestResultsRoot)));
}
}
@@ -215,8 +216,6 @@ partial class Build : NukeBuild
RunCoreTest("Avalonia.DesignerSupport.Tests");
});
- [PackageExecutable("JetBrains.dotMemoryUnit", "dotMemoryUnit.exe")] readonly Tool DotMemoryUnit;
-
Target RunLeakTests => _ => _
.OnlyWhenStatic(() => !Parameters.SkipTests && Parameters.IsRunningOnWindows)
.DependsOn(Compile)
@@ -224,12 +223,9 @@ partial class Build : NukeBuild
{
void DoMemoryTest()
{
- var testAssembly = "tests\\Avalonia.LeakTests\\bin\\Release\\net461\\Avalonia.LeakTests.dll";
- DotMemoryUnit(
- $"{XunitPath.DoubleQuoteIfNeeded()} --propagate-exit-code -- {testAssembly}",
- timeout: 120_000);
+ RunCoreTest("Avalonia.LeakTests");
}
- ControlFlow.ExecuteWithRetry(DoMemoryTest, waitInSeconds: 3);
+ ControlFlow.ExecuteWithRetry(DoMemoryTest, delay: TimeSpan.FromMilliseconds(3));
});
Target ZipFiles => _ => _
@@ -283,6 +279,14 @@ partial class Build : NukeBuild
.DependsOn(Package)
.DependsOn(ZipFiles);
+ Target GenerateCppHeaders => _ => _.Executes(() =>
+ {
+ var file = MicroComCodeGenerator.Parse(
+ File.ReadAllText(RootDirectory / "src" / "Avalonia.Native" / "avn.idl"));
+ File.WriteAllText(RootDirectory / "native" / "Avalonia.Native" / "inc" / "avalonia-native.h",
+ file.GenerateCppHeader());
+ });
+
public static int Main() =>
RuntimeInformation.IsOSPlatform(OSPlatform.Windows)
diff --git a/nukebuild/BuildParameters.cs b/nukebuild/BuildParameters.cs
index 1826623674..dfa914d1db 100644
--- a/nukebuild/BuildParameters.cs
+++ b/nukebuild/BuildParameters.cs
@@ -74,11 +74,11 @@ public partial class Build
MSBuildSolution = RootDirectory / "dirs.proj";
// PARAMETERS
- IsLocalBuild = Host == HostType.Console;
+ IsLocalBuild = NukeBuild.IsLocalBuild;
IsRunningOnUnix = Environment.OSVersion.Platform == PlatformID.Unix ||
Environment.OSVersion.Platform == PlatformID.MacOSX;
IsRunningOnWindows = RuntimeInformation.IsOSPlatform(OSPlatform.Windows);
- IsRunningOnAzure = Host == HostType.AzurePipelines ||
+ IsRunningOnAzure = Host is AzurePipelines ||
Environment.GetEnvironmentVariable("LOGNAME") == "vsts";
if (IsRunningOnAzure)
diff --git a/nukebuild/BuildTasksPatcher.cs b/nukebuild/BuildTasksPatcher.cs
index e3766ae23f..5fd331035a 100644
--- a/nukebuild/BuildTasksPatcher.cs
+++ b/nukebuild/BuildTasksPatcher.cs
@@ -17,8 +17,12 @@ public class BuildTasksPatcher
{
if (entry.Name == "Avalonia.Build.Tasks.dll")
{
- var temp = Path.Combine(Path.GetTempPath(), Guid.NewGuid() + ".dll");
+ var tempDir = Path.Combine(Path.GetTempPath(), Guid.NewGuid().ToString());
+ Directory.CreateDirectory(tempDir);
+ var temp = Path.Combine(tempDir, Guid.NewGuid() + ".dll");
var output = temp + ".output";
+ File.Copy(typeof(Microsoft.Build.Framework.ITask).Assembly.GetModules()[0].FullyQualifiedName,
+ Path.Combine(tempDir, "Microsoft.Build.Framework.dll"));
var patched = new MemoryStream();
try
{
@@ -57,10 +61,8 @@ public class BuildTasksPatcher
{
try
{
- if (File.Exists(temp))
- File.Delete(temp);
- if (File.Exists(output))
- File.Delete(output);
+ if(Directory.Exists(tempDir))
+ Directory.Delete(tempDir, true);
}
catch
{
diff --git a/nukebuild/DotNetConfigHelper.cs b/nukebuild/DotNetConfigHelper.cs
index 932525288c..eca1e2684d 100644
--- a/nukebuild/DotNetConfigHelper.cs
+++ b/nukebuild/DotNetConfigHelper.cs
@@ -46,7 +46,7 @@ public class DotNetConfigHelper
public DotNetConfigHelper SetVerbosity(DotNetVerbosity verbosity)
{
Build = Build?.SetVerbosity(verbosity);
- Pack = Pack?.SetVerbostiy(verbosity);
+ Pack = Pack?.SetVerbosity(verbosity);
Test = Test?.SetVerbosity(verbosity);
return this;
}
@@ -54,4 +54,4 @@ public class DotNetConfigHelper
public static implicit operator DotNetConfigHelper(DotNetBuildSettings s) => new DotNetConfigHelper(s);
public static implicit operator DotNetConfigHelper(DotNetPackSettings s) => new DotNetConfigHelper(s);
public static implicit operator DotNetConfigHelper(DotNetTestSettings s) => new DotNetConfigHelper(s);
-}
\ No newline at end of file
+}
diff --git a/nukebuild/MicroComGen.cs b/nukebuild/MicroComGen.cs
deleted file mode 100644
index b1e546cb97..0000000000
--- a/nukebuild/MicroComGen.cs
+++ /dev/null
@@ -1,14 +0,0 @@
-using System.IO;
-using MicroCom.CodeGenerator;
-using Nuke.Common;
-
-partial class Build : NukeBuild
-{
- Target GenerateCppHeaders => _ => _.Executes(() =>
- {
- var file = MicroComCodeGenerator.Parse(
- File.ReadAllText(RootDirectory / "src" / "Avalonia.Native" / "avn.idl"));
- File.WriteAllText(RootDirectory / "native" / "Avalonia.Native" / "inc" / "avalonia-native.h",
- file.GenerateCppHeader());
- });
-}
\ No newline at end of file
diff --git a/nukebuild/Shims.cs b/nukebuild/Shims.cs
index 1ac14bf622..6f79972ad6 100644
--- a/nukebuild/Shims.cs
+++ b/nukebuild/Shims.cs
@@ -49,7 +49,11 @@ public partial class Build
{
if (fsEntry is FileInfo)
{
+#if NET6
var relPath = Path.GetRelativePath(rootPath, fsEntry.FullName);
+#else
+ var relPath = GetRelativePath(rootPath, fsEntry.FullName);
+#endif
AddFile(fsEntry.FullName, relPath);
}
}
@@ -78,6 +82,17 @@ public partial class Build
}
}
+ private static string GetRelativePath(string relativeTo, string path)
+ {
+ var uri = new Uri(relativeTo);
+ var rel = Uri.UnescapeDataString(uri.MakeRelativeUri(new Uri(path)).ToString()).Replace(Path.AltDirectorySeparatorChar, Path.DirectorySeparatorChar);
+ if (rel.Contains(Path.DirectorySeparatorChar.ToString()) == false)
+ {
+ rel = $".{Path.DirectorySeparatorChar}{rel}";
+ }
+ return rel;
+ }
+
class NumergeNukeLogger : INumergeLogger
{
public void Log(NumergeLogLevel level, string message)
diff --git a/nukebuild/_build.csproj b/nukebuild/_build.csproj
index b2c58e2292..8c0d824298 100644
--- a/nukebuild/_build.csproj
+++ b/nukebuild/_build.csproj
@@ -1,41 +1,48 @@
-
Exe
- netcoreapp3.1
false
False
- CS0649;CS0169
+ CS0649;CS0169;SYSLIB0011
+ 1
+ net7.0
+
-
-
+
-
-
+
+
+
+
+ all
+ runtime; build; native; contentfiles; analyzers; buildtransitive
+
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/nukebuild/il-repack b/nukebuild/il-repack
new file mode 160000
index 0000000000..892f079ea8
--- /dev/null
+++ b/nukebuild/il-repack
@@ -0,0 +1 @@
+Subproject commit 892f079ea8cb0c178f0a68f53a7a7eac13acdda9
diff --git a/src/Avalonia.Base/Platform/Storage/IStorageFile.cs b/src/Avalonia.Base/Platform/Storage/IStorageFile.cs
index 46aa6efa72..4aa84e3ec4 100644
--- a/src/Avalonia.Base/Platform/Storage/IStorageFile.cs
+++ b/src/Avalonia.Base/Platform/Storage/IStorageFile.cs
@@ -18,6 +18,7 @@ public interface IStorageFile : IStorageItem
///
/// Opens a stream for read access.
///
+ ///
Task OpenReadAsync();
///
@@ -28,5 +29,6 @@ public interface IStorageFile : IStorageItem
///
/// Opens stream for writing to the file.
///
+ ///
Task OpenWriteAsync();
}
diff --git a/src/Avalonia.Base/Properties/AssemblyInfo.cs b/src/Avalonia.Base/Properties/AssemblyInfo.cs
index c8368e6d7a..d5e01087ef 100644
--- a/src/Avalonia.Base/Properties/AssemblyInfo.cs
+++ b/src/Avalonia.Base/Properties/AssemblyInfo.cs
@@ -30,4 +30,5 @@ using Avalonia.Metadata;
[assembly: InternalsVisibleTo("Avalonia.Skia.UnitTests, PublicKey=0024000004800000940000000602000000240000525341310004000001000100c1bba1142285fe0419326fb25866ba62c47e6c2b5c1ab0c95b46413fad375471232cb81706932e1cef38781b9ebd39d5100401bacb651c6c5bbf59e571e81b3bc08d2a622004e08b1a6ece82a7e0b9857525c86d2b95fab4bc3dce148558d7f3ae61aa3a234086902aeface87d9dfdd32b9d2fe3c6dd4055b5ab4b104998bd87")]
[assembly: InternalsVisibleTo("Avalonia.UnitTests, PublicKey=0024000004800000940000000602000000240000525341310004000001000100c1bba1142285fe0419326fb25866ba62c47e6c2b5c1ab0c95b46413fad375471232cb81706932e1cef38781b9ebd39d5100401bacb651c6c5bbf59e571e81b3bc08d2a622004e08b1a6ece82a7e0b9857525c86d2b95fab4bc3dce148558d7f3ae61aa3a234086902aeface87d9dfdd32b9d2fe3c6dd4055b5ab4b104998bd87")]
[assembly: InternalsVisibleTo("Avalonia.Web.Blazor, PublicKey=0024000004800000940000000602000000240000525341310004000001000100c1bba1142285fe0419326fb25866ba62c47e6c2b5c1ab0c95b46413fad375471232cb81706932e1cef38781b9ebd39d5100401bacb651c6c5bbf59e571e81b3bc08d2a622004e08b1a6ece82a7e0b9857525c86d2b95fab4bc3dce148558d7f3ae61aa3a234086902aeface87d9dfdd32b9d2fe3c6dd4055b5ab4b104998bd87")]
+[assembly: InternalsVisibleTo("Avalonia.Web, PublicKey=0024000004800000940000000602000000240000525341310004000001000100c1bba1142285fe0419326fb25866ba62c47e6c2b5c1ab0c95b46413fad375471232cb81706932e1cef38781b9ebd39d5100401bacb651c6c5bbf59e571e81b3bc08d2a622004e08b1a6ece82a7e0b9857525c86d2b95fab4bc3dce148558d7f3ae61aa3a234086902aeface87d9dfdd32b9d2fe3c6dd4055b5ab4b104998bd87")]
[assembly: InternalsVisibleTo("DynamicProxyGenAssembly2, PublicKey=0024000004800000940000000602000000240000525341310004000001000100c547cac37abd99c8db225ef2f6c8a3602f3b3606cc9891605d02baa56104f4cfc0734aa39b93bf7852f7d9266654753cc297e7d2edfe0bac1cdcf9f717241550e0a7b191195b7667bb4f64bcb8e2121380fd1d9d46ad2d92d2d15605093924cceaf74c4861eff62abf69b9291ed0a340e113be11e6a7d3113e92484cf7045cc7")]
diff --git a/src/Avalonia.Base/Utilities/AvaloniaResourcesIndex.cs b/src/Avalonia.Base/Utilities/AvaloniaResourcesIndex.cs
index bd3b86f06d..b8692bb771 100644
--- a/src/Avalonia.Base/Utilities/AvaloniaResourcesIndex.cs
+++ b/src/Avalonia.Base/Utilities/AvaloniaResourcesIndex.cs
@@ -1,9 +1,7 @@
using System;
using System.Collections.Generic;
using System.IO;
-using System.Runtime.CompilerServices;
using System.Runtime.Serialization;
-using System.Runtime.Serialization.Json;
using System.Xml.Linq;
using System.Linq;
diff --git a/src/Avalonia.Build.Tasks/Avalonia.Build.Tasks.csproj b/src/Avalonia.Build.Tasks/Avalonia.Build.Tasks.csproj
index 8387c62cad..22c410198f 100644
--- a/src/Avalonia.Build.Tasks/Avalonia.Build.Tasks.csproj
+++ b/src/Avalonia.Build.Tasks/Avalonia.Build.Tasks.csproj
@@ -105,7 +105,7 @@
-
+
diff --git a/src/Avalonia.Build.Tasks/GenerateAvaloniaResourcesTask.cs b/src/Avalonia.Build.Tasks/GenerateAvaloniaResourcesTask.cs
index c20b2f656e..75758d1315 100644
--- a/src/Avalonia.Build.Tasks/GenerateAvaloniaResourcesTask.cs
+++ b/src/Avalonia.Build.Tasks/GenerateAvaloniaResourcesTask.cs
@@ -3,7 +3,6 @@ using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.Serialization;
-using System.Runtime.Serialization.Json;
using System.Text;
using Avalonia.Markup.Xaml.PortableXaml;
using Avalonia.Utilities;
diff --git a/src/Avalonia.Controls.ColorPicker/ColorPalettes/MaterialColorPalette.cs b/src/Avalonia.Controls.ColorPicker/ColorPalettes/MaterialColorPalette.cs
new file mode 100644
index 0000000000..5cf5662ede
--- /dev/null
+++ b/src/Avalonia.Controls.ColorPicker/ColorPalettes/MaterialColorPalette.cs
@@ -0,0 +1,359 @@
+using Avalonia.Media;
+using Avalonia.Utilities;
+
+namespace Avalonia.Controls
+{
+ ///
+ /// Implements a reduced version of the 2014 Material Design color palette.
+ ///
+ ///
+ /// This palette is based on the one outlined here:
+ ///
+ /// https://material.io/design/color/the-color-system.html#tools-for-picking-colors
+ ///
+ /// In order to make the palette uniform and rectangular the following
+ /// alterations were made:
+ ///
+ /// 1. The A100-A700 shades of each color are excluded.
+ /// These shades do not exist for all colors (brown/gray).
+ /// 2. Black/White are stand-alone and are also excluded.
+ ///
+ ///
+ public class MaterialColorPalette : IColorPalette
+ {
+ // See: https://material.io/design/color/the-color-system.html#tools-for-picking-colors
+ // This is a reduced palette for uniformity
+ private static Color[,]? _colorChart = null;
+ private static int _colorChartColorCount = 0;
+ private static int _colorChartShadeCount = 0;
+ private static object _colorChartMutex = new object();
+
+ ///
+ /// Initializes all color chart colors.
+ ///
+ ///
+ /// This is pulled out separately to lazy load for performance.
+ /// If no material color palette is ever used, no colors will be created.
+ ///
+ private void InitColorChart()
+ {
+ lock (_colorChartMutex)
+ {
+ _colorChart = new Color[,]
+ {
+ // Red
+ {
+ Color.FromArgb(0xFF, 0xFF, 0xEB, 0xEE),
+ Color.FromArgb(0xFF, 0xFF, 0xCD, 0xD2),
+ Color.FromArgb(0xFF, 0xEF, 0x9A, 0x9A),
+ Color.FromArgb(0xFF, 0xE5, 0x73, 0x73),
+ Color.FromArgb(0xFF, 0xEF, 0x53, 0x50),
+ Color.FromArgb(0xFF, 0xF4, 0x43, 0x36),
+ Color.FromArgb(0xFF, 0xE5, 0x39, 0x35),
+ Color.FromArgb(0xFF, 0xD3, 0x2F, 0x2F),
+ Color.FromArgb(0xFF, 0xC6, 0x28, 0x28),
+ Color.FromArgb(0xFF, 0xB7, 0x1C, 0x1C),
+ },
+
+ // Pink
+ {
+ Color.FromArgb(0xFF, 0xFC, 0xE4, 0xEC),
+ Color.FromArgb(0xFF, 0xF8, 0xBB, 0xD0),
+ Color.FromArgb(0xFF, 0xF4, 0x8F, 0xB1),
+ Color.FromArgb(0xFF, 0xF0, 0x62, 0x92),
+ Color.FromArgb(0xFF, 0xEC, 0x40, 0x7A),
+ Color.FromArgb(0xFF, 0xE9, 0x1E, 0x63),
+ Color.FromArgb(0xFF, 0xD8, 0x1B, 0x60),
+ Color.FromArgb(0xFF, 0xC2, 0x18, 0x5B),
+ Color.FromArgb(0xFF, 0xAD, 0x14, 0x57),
+ Color.FromArgb(0xFF, 0x88, 0x0E, 0x4F),
+ },
+
+ // Purple
+ {
+ Color.FromArgb(0xFF, 0xF3, 0xE5, 0xF5),
+ Color.FromArgb(0xFF, 0xE1, 0xBE, 0xE7),
+ Color.FromArgb(0xFF, 0xCE, 0x93, 0xD8),
+ Color.FromArgb(0xFF, 0xBA, 0x68, 0xC8),
+ Color.FromArgb(0xFF, 0xAB, 0x47, 0xBC),
+ Color.FromArgb(0xFF, 0x9C, 0x27, 0xB0),
+ Color.FromArgb(0xFF, 0x8E, 0x24, 0xAA),
+ Color.FromArgb(0xFF, 0x7B, 0x1F, 0xA2),
+ Color.FromArgb(0xFF, 0x6A, 0x1B, 0x9A),
+ Color.FromArgb(0xFF, 0x4A, 0x14, 0x8C),
+ },
+
+ // Deep Purple
+ {
+ Color.FromArgb(0xFF, 0xED, 0xE7, 0xF6),
+ Color.FromArgb(0xFF, 0xD1, 0xC4, 0xE9),
+ Color.FromArgb(0xFF, 0xB3, 0x9D, 0xDB),
+ Color.FromArgb(0xFF, 0x95, 0x75, 0xCD),
+ Color.FromArgb(0xFF, 0x7E, 0x57, 0xC2),
+ Color.FromArgb(0xFF, 0x67, 0x3A, 0xB7),
+ Color.FromArgb(0xFF, 0x5E, 0x35, 0xB1),
+ Color.FromArgb(0xFF, 0x51, 0x2D, 0xA8),
+ Color.FromArgb(0xFF, 0x45, 0x27, 0xA0),
+ Color.FromArgb(0xFF, 0x31, 0x1B, 0x92),
+ },
+
+ // Indigo
+ {
+ Color.FromArgb(0xFF, 0xE8, 0xEA, 0xF6),
+ Color.FromArgb(0xFF, 0xC5, 0xCA, 0xE9),
+ Color.FromArgb(0xFF, 0x9F, 0xA8, 0xDA),
+ Color.FromArgb(0xFF, 0x79, 0x86, 0xCB),
+ Color.FromArgb(0xFF, 0x5C, 0x6B, 0xC0),
+ Color.FromArgb(0xFF, 0x3F, 0x51, 0xB5),
+ Color.FromArgb(0xFF, 0x39, 0x49, 0xAB),
+ Color.FromArgb(0xFF, 0x30, 0x3F, 0x9F),
+ Color.FromArgb(0xFF, 0x28, 0x35, 0x93),
+ Color.FromArgb(0xFF, 0x1A, 0x23, 0x7E),
+ },
+
+ // Blue
+ {
+ Color.FromArgb(0xFF, 0xE3, 0xF2, 0xFD),
+ Color.FromArgb(0xFF, 0xBB, 0xDE, 0xFB),
+ Color.FromArgb(0xFF, 0x90, 0xCA, 0xF9),
+ Color.FromArgb(0xFF, 0x64, 0xB5, 0xF6),
+ Color.FromArgb(0xFF, 0x42, 0xA5, 0xF5),
+ Color.FromArgb(0xFF, 0x21, 0x96, 0xF3),
+ Color.FromArgb(0xFF, 0x1E, 0x88, 0xE5),
+ Color.FromArgb(0xFF, 0x19, 0x76, 0xD2),
+ Color.FromArgb(0xFF, 0x15, 0x65, 0xC0),
+ Color.FromArgb(0xFF, 0x0D, 0x47, 0xA1),
+ },
+
+ // Light Blue
+ {
+ Color.FromArgb(0xFF, 0xE1, 0xF5, 0xFE),
+ Color.FromArgb(0xFF, 0xB3, 0xE5, 0xFC),
+ Color.FromArgb(0xFF, 0x81, 0xD4, 0xFA),
+ Color.FromArgb(0xFF, 0x4F, 0xC3, 0xF7),
+ Color.FromArgb(0xFF, 0x29, 0xB6, 0xF6),
+ Color.FromArgb(0xFF, 0x03, 0xA9, 0xF4),
+ Color.FromArgb(0xFF, 0x03, 0x9B, 0xE5),
+ Color.FromArgb(0xFF, 0x02, 0x88, 0xD1),
+ Color.FromArgb(0xFF, 0x02, 0x77, 0xBD),
+ Color.FromArgb(0xFF, 0x01, 0x57, 0x9B),
+ },
+
+ // Cyan
+ {
+ Color.FromArgb(0xFF, 0xE0, 0xF7, 0xFA),
+ Color.FromArgb(0xFF, 0xB2, 0xEB, 0xF2),
+ Color.FromArgb(0xFF, 0x80, 0xDE, 0xEA),
+ Color.FromArgb(0xFF, 0x4D, 0xD0, 0xE1),
+ Color.FromArgb(0xFF, 0x26, 0xC6, 0xDA),
+ Color.FromArgb(0xFF, 0x00, 0xBC, 0xD4),
+ Color.FromArgb(0xFF, 0x00, 0xAC, 0xC1),
+ Color.FromArgb(0xFF, 0x00, 0x97, 0xA7),
+ Color.FromArgb(0xFF, 0x00, 0x83, 0x8F),
+ Color.FromArgb(0xFF, 0x00, 0x60, 0x64),
+ },
+
+ // Teal
+ {
+ Color.FromArgb(0xFF, 0xE0, 0xF2, 0xF1),
+ Color.FromArgb(0xFF, 0xB2, 0xDF, 0xDB),
+ Color.FromArgb(0xFF, 0x80, 0xCB, 0xC4),
+ Color.FromArgb(0xFF, 0x4D, 0xB6, 0xAC),
+ Color.FromArgb(0xFF, 0x26, 0xA6, 0x9A),
+ Color.FromArgb(0xFF, 0x00, 0x96, 0x88),
+ Color.FromArgb(0xFF, 0x00, 0x89, 0x7B),
+ Color.FromArgb(0xFF, 0x00, 0x79, 0x6B),
+ Color.FromArgb(0xFF, 0x00, 0x69, 0x5C),
+ Color.FromArgb(0xFF, 0x00, 0x4D, 0x40),
+ },
+
+ // Green
+ {
+ Color.FromArgb(0xFF, 0xE8, 0xF5, 0xE9),
+ Color.FromArgb(0xFF, 0xC8, 0xE6, 0xC9),
+ Color.FromArgb(0xFF, 0xA5, 0xD6, 0xA7),
+ Color.FromArgb(0xFF, 0x81, 0xC7, 0x84),
+ Color.FromArgb(0xFF, 0x66, 0xBB, 0x6A),
+ Color.FromArgb(0xFF, 0x4C, 0xAF, 0x50),
+ Color.FromArgb(0xFF, 0x43, 0xA0, 0x47),
+ Color.FromArgb(0xFF, 0x38, 0x8E, 0x3C),
+ Color.FromArgb(0xFF, 0x2E, 0x7D, 0x32),
+ Color.FromArgb(0xFF, 0x1B, 0x5E, 0x20),
+ },
+
+ // Light Green
+ {
+ Color.FromArgb(0xFF, 0xF1, 0xF8, 0xE9),
+ Color.FromArgb(0xFF, 0xDC, 0xED, 0xC8),
+ Color.FromArgb(0xFF, 0xC5, 0xE1, 0xA5),
+ Color.FromArgb(0xFF, 0xAE, 0xD5, 0x81),
+ Color.FromArgb(0xFF, 0x9C, 0xCC, 0x65),
+ Color.FromArgb(0xFF, 0x8B, 0xC3, 0x4A),
+ Color.FromArgb(0xFF, 0x7C, 0xB3, 0x42),
+ Color.FromArgb(0xFF, 0x68, 0x9F, 0x38),
+ Color.FromArgb(0xFF, 0x55, 0x8B, 0x2F),
+ Color.FromArgb(0xFF, 0x33, 0x69, 0x1E),
+ },
+
+ // Lime
+ {
+ Color.FromArgb(0xFF, 0xF9, 0xFB, 0xE7),
+ Color.FromArgb(0xFF, 0xF0, 0xF4, 0xC3),
+ Color.FromArgb(0xFF, 0xE6, 0xEE, 0x9C),
+ Color.FromArgb(0xFF, 0xDC, 0xE7, 0x75),
+ Color.FromArgb(0xFF, 0xD4, 0xE1, 0x57),
+ Color.FromArgb(0xFF, 0xCD, 0xDC, 0x39),
+ Color.FromArgb(0xFF, 0xC0, 0xCA, 0x33),
+ Color.FromArgb(0xFF, 0xAF, 0xB4, 0x2B),
+ Color.FromArgb(0xFF, 0x9E, 0x9D, 0x24),
+ Color.FromArgb(0xFF, 0x82, 0x77, 0x17),
+ },
+
+ // Yellow
+ {
+ Color.FromArgb(0xFF, 0xFF, 0xFD, 0xE7),
+ Color.FromArgb(0xFF, 0xFF, 0xF9, 0xC4),
+ Color.FromArgb(0xFF, 0xFF, 0xF5, 0x9D),
+ Color.FromArgb(0xFF, 0xFF, 0xF1, 0x76),
+ Color.FromArgb(0xFF, 0xFF, 0xEE, 0x58),
+ Color.FromArgb(0xFF, 0xFF, 0xEB, 0x3B),
+ Color.FromArgb(0xFF, 0xFD, 0xD8, 0x35),
+ Color.FromArgb(0xFF, 0xFB, 0xC0, 0x2D),
+ Color.FromArgb(0xFF, 0xF9, 0xA8, 0x25),
+ Color.FromArgb(0xFF, 0xF5, 0x7F, 0x17),
+ },
+
+ // Amber
+ {
+ Color.FromArgb(0xFF, 0xFF, 0xF8, 0xE1),
+ Color.FromArgb(0xFF, 0xFF, 0xEC, 0xB3),
+ Color.FromArgb(0xFF, 0xFF, 0xE0, 0x82),
+ Color.FromArgb(0xFF, 0xFF, 0xD5, 0x4F),
+ Color.FromArgb(0xFF, 0xFF, 0xCA, 0x28),
+ Color.FromArgb(0xFF, 0xFF, 0xC1, 0x07),
+ Color.FromArgb(0xFF, 0xFF, 0xB3, 0x00),
+ Color.FromArgb(0xFF, 0xFF, 0xA0, 0x00),
+ Color.FromArgb(0xFF, 0xFF, 0x8F, 0x00),
+ Color.FromArgb(0xFF, 0xFF, 0x6F, 0x00),
+ },
+
+ // Orange
+ {
+ Color.FromArgb(0xFF, 0xFF, 0xF3, 0xE0),
+ Color.FromArgb(0xFF, 0xFF, 0xE0, 0xB2),
+ Color.FromArgb(0xFF, 0xFF, 0xCC, 0x80),
+ Color.FromArgb(0xFF, 0xFF, 0xB7, 0x4D),
+ Color.FromArgb(0xFF, 0xFF, 0xA7, 0x26),
+ Color.FromArgb(0xFF, 0xFF, 0x98, 0x00),
+ Color.FromArgb(0xFF, 0xFB, 0x8C, 0x00),
+ Color.FromArgb(0xFF, 0xF5, 0x7C, 0x00),
+ Color.FromArgb(0xFF, 0xEF, 0x6C, 0x00),
+ Color.FromArgb(0xFF, 0xE6, 0x51, 0x00),
+ },
+
+ // Deep Orange
+ {
+ Color.FromArgb(0xFF, 0xFB, 0xE9, 0xE7),
+ Color.FromArgb(0xFF, 0xFF, 0xCC, 0xBC),
+ Color.FromArgb(0xFF, 0xFF, 0xAB, 0x91),
+ Color.FromArgb(0xFF, 0xFF, 0x8A, 0x65),
+ Color.FromArgb(0xFF, 0xFF, 0x70, 0x43),
+ Color.FromArgb(0xFF, 0xFF, 0x57, 0x22),
+ Color.FromArgb(0xFF, 0xF4, 0x51, 0x1E),
+ Color.FromArgb(0xFF, 0xE6, 0x4A, 0x19),
+ Color.FromArgb(0xFF, 0xD8, 0x43, 0x15),
+ Color.FromArgb(0xFF, 0xBF, 0x36, 0x0C),
+ },
+
+ // Brown
+ {
+ Color.FromArgb(0xFF, 0xEF, 0xEB, 0xE9),
+ Color.FromArgb(0xFF, 0xD7, 0xCC, 0xC8),
+ Color.FromArgb(0xFF, 0xBC, 0xAA, 0xA4),
+ Color.FromArgb(0xFF, 0xA1, 0x88, 0x7F),
+ Color.FromArgb(0xFF, 0x8D, 0x6E, 0x63),
+ Color.FromArgb(0xFF, 0x79, 0x55, 0x48),
+ Color.FromArgb(0xFF, 0x6D, 0x4C, 0x41),
+ Color.FromArgb(0xFF, 0x5D, 0x40, 0x37),
+ Color.FromArgb(0xFF, 0x4E, 0x34, 0x2E),
+ Color.FromArgb(0xFF, 0x3E, 0x27, 0x23),
+ },
+
+ // Gray
+ {
+ Color.FromArgb(0xFF, 0xFA, 0xFA, 0xFA),
+ Color.FromArgb(0xFF, 0xF5, 0xF5, 0xF5),
+ Color.FromArgb(0xFF, 0xEE, 0xEE, 0xEE),
+ Color.FromArgb(0xFF, 0xE0, 0xE0, 0xE0),
+ Color.FromArgb(0xFF, 0xBD, 0xBD, 0xBD),
+ Color.FromArgb(0xFF, 0x9E, 0x9E, 0x9E),
+ Color.FromArgb(0xFF, 0x75, 0x75, 0x75),
+ Color.FromArgb(0xFF, 0x61, 0x61, 0x61),
+ Color.FromArgb(0xFF, 0x42, 0x42, 0x42),
+ Color.FromArgb(0xFF, 0x21, 0x21, 0x21),
+ },
+
+ // Blue Gray
+ {
+ Color.FromArgb(0xFF, 0xEC, 0xEF, 0xF1),
+ Color.FromArgb(0xFF, 0xCF, 0xD8, 0xDC),
+ Color.FromArgb(0xFF, 0xB0, 0xBE, 0xC5),
+ Color.FromArgb(0xFF, 0x90, 0xA4, 0xAE),
+ Color.FromArgb(0xFF, 0x78, 0x90, 0x9C),
+ Color.FromArgb(0xFF, 0x60, 0x7D, 0x8B),
+ Color.FromArgb(0xFF, 0x54, 0x6E, 0x7A),
+ Color.FromArgb(0xFF, 0x45, 0x5A, 0x64),
+ Color.FromArgb(0xFF, 0x37, 0x47, 0x4F),
+ Color.FromArgb(0xFF, 0x26, 0x32, 0x38),
+ },
+ };
+
+ _colorChartColorCount = _colorChart.GetLength(0);
+ _colorChartShadeCount = _colorChart.GetLength(1);
+ }
+
+ return;
+ }
+
+ ///
+ public int ColorCount
+ {
+ get
+ {
+ if (_colorChart == null)
+ {
+ InitColorChart();
+ }
+
+ return _colorChartColorCount;
+ }
+ }
+
+ ///
+ public int ShadeCount
+ {
+ get
+ {
+ if (_colorChart == null)
+ {
+ InitColorChart();
+ }
+
+ return _colorChartShadeCount;
+ }
+ }
+
+ ///
+ public Color GetColor(int colorIndex, int shadeIndex)
+ {
+ if (_colorChart == null)
+ {
+ InitColorChart();
+ }
+
+ return _colorChart![
+ MathUtilities.Clamp(colorIndex, 0, _colorChartColorCount - 1),
+ MathUtilities.Clamp(shadeIndex, 0, _colorChartShadeCount - 1)];
+ }
+ }
+}
diff --git a/src/Avalonia.Controls/ComboBox.cs b/src/Avalonia.Controls/ComboBox.cs
index 05be5ad00d..54196bdf1a 100644
--- a/src/Avalonia.Controls/ComboBox.cs
+++ b/src/Avalonia.Controls/ComboBox.cs
@@ -21,8 +21,11 @@ namespace Avalonia.Controls
/// A drop-down list control.
///
[TemplatePart("PART_Popup", typeof(Popup))]
+ [PseudoClasses(pcDropdownOpen, pcPressed)]
public class ComboBox : SelectingItemsControl
{
+ public const string pcDropdownOpen = ":dropdownopen";
+ public const string pcPressed = ":pressed";
///
/// The default value for the property.
///
@@ -95,6 +98,7 @@ namespace Avalonia.Controls
SelectedItemProperty.Changed.AddClassHandler((x, e) => x.SelectedItemChanged(e));
KeyDownEvent.AddClassHandler((x, e) => x.OnKeyDown(e), Interactivity.RoutingStrategies.Tunnel);
IsTextSearchEnabledProperty.OverrideDefaultValue(true);
+ IsDropDownOpenProperty.Changed.AddClassHandler((x, e) => x.DropdownChanged(e));
}
///
@@ -267,6 +271,20 @@ namespace Avalonia.Controls
}
}
+ ///
+ protected override void OnPointerPressed(PointerPressedEventArgs e)
+ {
+ base.OnPointerPressed(e);
+ if(!e.Handled && e.Source is IVisual source)
+ {
+ if (_popup?.IsInsidePopup(source) == true)
+ {
+ return;
+ }
+ }
+ PseudoClasses.Set(pcPressed, true);
+ }
+
///
protected override void OnPointerReleased(PointerReleasedEventArgs e)
{
@@ -286,10 +304,12 @@ namespace Avalonia.Controls
e.Handled = true;
}
}
-
+ PseudoClasses.Set(pcPressed, false);
base.OnPointerReleased(e);
+
}
+
///
protected override void OnApplyTemplate(TemplateAppliedEventArgs e)
{
@@ -470,5 +490,11 @@ namespace Avalonia.Controls
MoveSelection(NavigationDirection.Previous, WrapSelection);
}
}
+
+ private void DropdownChanged(AvaloniaPropertyChangedEventArgs e)
+ {
+ bool newValue = e.GetNewValue();
+ PseudoClasses.Set(pcDropdownOpen, newValue);
+ }
}
}
diff --git a/src/Avalonia.Themes.Fluent/Controls/ComboBox.xaml b/src/Avalonia.Themes.Fluent/Controls/ComboBox.xaml
index af3b5bc51e..4aa0ddc23a 100644
--- a/src/Avalonia.Themes.Fluent/Controls/ComboBox.xaml
+++ b/src/Avalonia.Themes.Fluent/Controls/ComboBox.xaml
@@ -57,17 +57,8 @@
-
-
+
-
diff --git a/src/Avalonia.Themes.Fluent/Controls/DatePicker.xaml b/src/Avalonia.Themes.Fluent/Controls/DatePicker.xaml
index 1d6ee8aaca..6f1e4fccfe 100644
--- a/src/Avalonia.Themes.Fluent/Controls/DatePicker.xaml
+++ b/src/Avalonia.Themes.Fluent/Controls/DatePicker.xaml
@@ -153,11 +153,11 @@
-
-
-
diff --git a/src/Avalonia.Themes.Fluent/Controls/TimePicker.xaml b/src/Avalonia.Themes.Fluent/Controls/TimePicker.xaml
index caf1251d25..cb88eac2ba 100644
--- a/src/Avalonia.Themes.Fluent/Controls/TimePicker.xaml
+++ b/src/Avalonia.Themes.Fluent/Controls/TimePicker.xaml
@@ -181,11 +181,11 @@
-
-
diff --git a/src/Avalonia.Themes.Simple/Controls/DatePicker.xaml b/src/Avalonia.Themes.Simple/Controls/DatePicker.xaml
index 317a27435a..b4cf6313a6 100644
--- a/src/Avalonia.Themes.Simple/Controls/DatePicker.xaml
+++ b/src/Avalonia.Themes.Simple/Controls/DatePicker.xaml
@@ -170,7 +170,7 @@
-
diff --git a/src/Avalonia.Themes.Simple/Controls/TimePicker.xaml b/src/Avalonia.Themes.Simple/Controls/TimePicker.xaml
index 5aa717e9ee..e02e3d8194 100644
--- a/src/Avalonia.Themes.Simple/Controls/TimePicker.xaml
+++ b/src/Avalonia.Themes.Simple/Controls/TimePicker.xaml
@@ -189,7 +189,7 @@
-
diff --git a/src/Web/Avalonia.Web.Blazor/AvaloniaView.razor.cs b/src/Web/Avalonia.Web.Blazor/AvaloniaView.razor.cs
index 5b5951e800..0e64e98f1e 100644
--- a/src/Web/Avalonia.Web.Blazor/AvaloniaView.razor.cs
+++ b/src/Web/Avalonia.Web.Blazor/AvaloniaView.razor.cs
@@ -287,7 +287,6 @@ namespace Avalonia.Web.Blazor
// create the SkiaSharp context
if (_context == null)
{
- Console.WriteLine("create glcontext");
_glInterface = GRGlInterface.Create();
_context = GRContext.CreateGl(_glInterface);
diff --git a/src/Web/Avalonia.Web.Sample/Avalonia.Web.Sample.csproj b/src/Web/Avalonia.Web.Sample/Avalonia.Web.Sample.csproj
new file mode 100644
index 0000000000..13aad8c13e
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/Avalonia.Web.Sample.csproj
@@ -0,0 +1,41 @@
+
+
+ net7.0
+ browser-wasm
+ main.js
+ Exe
+ true
+ true
+ true
+ -sVERBOSE -sERROR_ON_UNDEFINED_SYMBOLS=0
+
+
+
+ true
+ true
+ full
+ true
+ true
+ true
+ -O3
+ -O3
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/Web/Avalonia.Web.Sample/EmbedSample.Browser.cs b/src/Web/Avalonia.Web.Sample/EmbedSample.Browser.cs
new file mode 100644
index 0000000000..5baa4a6b35
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/EmbedSample.Browser.cs
@@ -0,0 +1,44 @@
+using System;
+using System.Runtime.InteropServices.JavaScript;
+
+using Avalonia;
+using Avalonia.Platform;
+using Avalonia.Web;
+
+using ControlCatalog.Pages;
+
+namespace ControlCatalog.Web;
+
+public class EmbedSampleWeb : INativeDemoControl
+{
+ public IPlatformHandle CreateControl(bool isSecond, IPlatformHandle parent, Func createDefault)
+ {
+ if (isSecond)
+ {
+ var iframe = EmbedInterop.CreateElement("iframe");
+ iframe.SetProperty("src", "https://www.youtube.com/embed/kZCIporjJ70");
+
+ return new JSObjectControlHandle(iframe);
+ }
+ else
+ {
+ var defaultHandle = (JSObjectControlHandle)createDefault();
+
+ _ = JSHost.ImportAsync("embed.js", "./embed.js").ContinueWith(_ =>
+ {
+ EmbedInterop.AddAppButton(defaultHandle.Object);
+ });
+
+ return defaultHandle;
+ }
+ }
+}
+
+internal static partial class EmbedInterop
+{
+ [JSImport("globalThis.document.createElement")]
+ public static partial JSObject CreateElement(string tagName);
+
+ [JSImport("addAppButton", "embed.js")]
+ public static partial void AddAppButton(JSObject parentObject);
+}
diff --git a/src/Web/Avalonia.Web.Sample/Logo.svg b/src/Web/Avalonia.Web.Sample/Logo.svg
new file mode 100644
index 0000000000..9685a23af1
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/Logo.svg
@@ -0,0 +1,5 @@
+
diff --git a/src/Web/Avalonia.Web.Sample/Program.cs b/src/Web/Avalonia.Web.Sample/Program.cs
new file mode 100644
index 0000000000..52acabb0fa
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/Program.cs
@@ -0,0 +1,19 @@
+using Avalonia;
+using Avalonia.Web;
+using ControlCatalog;
+using ControlCatalog.Web;
+
+internal partial class Program
+{
+ private static void Main(string[] args)
+ {
+ BuildAvaloniaApp()
+ .AfterSetup(_ =>
+ {
+ ControlCatalog.Pages.EmbedSample.Implementation = new EmbedSampleWeb();
+ }).SetupBrowserApp("out");
+ }
+
+ public static AppBuilder BuildAvaloniaApp()
+ => AppBuilder.Configure();
+}
diff --git a/src/Web/Avalonia.Web.Sample/app.css b/src/Web/Avalonia.Web.Sample/app.css
new file mode 100644
index 0000000000..04ea5bee19
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/app.css
@@ -0,0 +1,38 @@
+#out {
+ height: 100vh;
+ width: 100vw
+}
+
+#avalonia-splash {
+ position: absolute;
+ height: 100%;
+ width: 100%;
+ color: whitesmoke;
+ background: #171C2C;
+ font-family: 'Nunito', sans-serif;
+}
+
+#avalonia-splash a{
+ color: whitesmoke;
+ text-decoration: none;
+}
+
+.center {
+ display: flex;
+ justify-content: center;
+ height: 250px;
+}
+
+.splash-close {
+ animation: fadeOut 1s forwards;
+}
+
+@keyframes fadeOut {
+ from {
+ opacity: 1;
+ }
+
+ to {
+ opacity: 0;
+ }
+}
diff --git a/src/Web/Avalonia.Web.Sample/embed.js b/src/Web/Avalonia.Web.Sample/embed.js
new file mode 100644
index 0000000000..f393c80314
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/embed.js
@@ -0,0 +1,11 @@
+export function addAppButton(parent) {
+ var button = globalThis.document.createElement('button');
+ button.innerText = 'Hello world';
+ var clickCount = 0;
+ button.onclick = () => {
+ clickCount++;
+ button.innerText = 'Click count ' + clickCount;
+ };
+ parent.appendChild(button);
+ return button;
+}
diff --git a/src/Web/Avalonia.Web.Sample/favicon.ico b/src/Web/Avalonia.Web.Sample/favicon.ico
new file mode 100644
index 0000000000..da8d49ff9b
Binary files /dev/null and b/src/Web/Avalonia.Web.Sample/favicon.ico differ
diff --git a/src/Web/Avalonia.Web.Sample/index.html b/src/Web/Avalonia.Web.Sample/index.html
new file mode 100644
index 0000000000..ee023790fb
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/index.html
@@ -0,0 +1,31 @@
+
+
+
+
+
+
+ Avalonia.Web.Sample
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/Web/Avalonia.Web.Sample/main.js b/src/Web/Avalonia.Web.Sample/main.js
new file mode 100644
index 0000000000..3683aea181
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/main.js
@@ -0,0 +1,19 @@
+// Licensed to the .NET Foundation under one or more agreements.
+// The .NET Foundation licenses this file to you under the MIT license.
+
+import { dotnet } from './dotnet.js'
+import { createAvaloniaRuntime } from './avalonia.js';
+
+const is_browser = typeof window != "undefined";
+if (!is_browser) throw new Error(`Expected to be running in a browser`);
+
+const dotnetRuntime = await dotnet
+ .withDiagnosticTracing(false)
+ .withApplicationArgumentsFromQuery()
+ .create();
+
+await createAvaloniaRuntime(dotnetRuntime);
+
+const config = dotnetRuntime.getConfig();
+
+await dotnetRuntime.runMainAndExit(config.mainAssemblyName, ["dotnet", "is", "great!"]);
diff --git a/src/Web/Avalonia.Web.Sample/runtimeconfig.template.json b/src/Web/Avalonia.Web.Sample/runtimeconfig.template.json
new file mode 100644
index 0000000000..8f0557352c
--- /dev/null
+++ b/src/Web/Avalonia.Web.Sample/runtimeconfig.template.json
@@ -0,0 +1,11 @@
+{
+ "wasmHostProperties": {
+ "perHostConfig": [
+ {
+ "name": "browser",
+ "html-path": "index.html",
+ "Host": "browser"
+ }
+ ]
+ }
+}
diff --git a/src/Web/Avalonia.Web/Avalonia.Web.csproj b/src/Web/Avalonia.Web/Avalonia.Web.csproj
new file mode 100644
index 0000000000..a4756a5e2b
--- /dev/null
+++ b/src/Web/Avalonia.Web/Avalonia.Web.csproj
@@ -0,0 +1,55 @@
+
+
+ net7.0
+ preview
+ enable
+ true
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ true
+ build\
+
+
+ true
+ build\;buildTransitive\
+
+
+ true
+ build/interop.js;buildTransitive/interop.js
+
+
+ true
+ build\wwwroot;buildTransitive\wwwroot
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/Web/Avalonia.Web/Avalonia.Web.props b/src/Web/Avalonia.Web/Avalonia.Web.props
new file mode 100644
index 0000000000..6c975cd284
--- /dev/null
+++ b/src/Web/Avalonia.Web/Avalonia.Web.props
@@ -0,0 +1,5 @@
+
+
+ $(EmccExtraLDFlags) --js-library="$(MSBuildThisFileDirectory)\interop.js"
+
+
diff --git a/src/Web/Avalonia.Web/Avalonia.Web.targets b/src/Web/Avalonia.Web/Avalonia.Web.targets
new file mode 100644
index 0000000000..d1bec2aa93
--- /dev/null
+++ b/src/Web/Avalonia.Web/Avalonia.Web.targets
@@ -0,0 +1,7 @@
+
+
+
+
+
+
+
diff --git a/src/Web/Avalonia.Web/AvaloniaView.cs b/src/Web/Avalonia.Web/AvaloniaView.cs
new file mode 100644
index 0000000000..e81620ffde
--- /dev/null
+++ b/src/Web/Avalonia.Web/AvaloniaView.cs
@@ -0,0 +1,451 @@
+using System;
+using System.Runtime.InteropServices.JavaScript;
+using Avalonia.Controls;
+using Avalonia.Controls.Embedding;
+using Avalonia.Controls.Platform;
+using Avalonia.Input;
+using Avalonia.Input.Raw;
+using Avalonia.Input.TextInput;
+using Avalonia.Rendering.Composition;
+using Avalonia.Threading;
+using Avalonia.Web.Interop;
+using Avalonia.Web.Skia;
+
+using SkiaSharp;
+
+namespace Avalonia.Web
+{
+ [System.Runtime.Versioning.SupportedOSPlatform("browser")] // gets rid of callsite warnings
+ public partial class AvaloniaView : ITextInputMethodImpl
+ {
+ private readonly BrowserTopLevelImpl _topLevelImpl;
+ private EmbeddableControlRoot _topLevel;
+
+ private readonly JSObject _containerElement;
+ private readonly JSObject _canvas;
+ private readonly JSObject _nativeControlsContainer;
+ private readonly JSObject _inputElement;
+ private readonly JSObject? _splash;
+
+ private GLInfo? _jsGlInfo = null;
+ private double _dpi = 1;
+ private Size _canvasSize = new(100.0, 100.0);
+
+ private GRContext? _context;
+ private GRGlInterface? _glInterface;
+ private const SKColorType ColorType = SKColorType.Rgba8888;
+
+ private bool _useGL;
+ private ITextInputMethodClient? _client;
+ private static int _canvasCount;
+
+ public AvaloniaView(string divId)
+ {
+ var host = DomHelper.GetElementById(divId);
+ if (host == null)
+ {
+ throw new Exception($"Element with id {divId} was not found in the html document.");
+ }
+
+ var hostContent = DomHelper.CreateAvaloniaHost(host);
+ if (hostContent == null)
+ {
+ throw new InvalidOperationException("Avalonia WASM host wasn't initialized.");
+ }
+
+ _containerElement = hostContent.GetPropertyAsJSObject("host")
+ ?? throw new InvalidOperationException("Host cannot be null");
+ _canvas = hostContent.GetPropertyAsJSObject("canvas")
+ ?? throw new InvalidOperationException("Canvas cannot be null");
+ _nativeControlsContainer = hostContent.GetPropertyAsJSObject("nativeHost")
+ ?? throw new InvalidOperationException("NativeHost cannot be null");
+ _inputElement = hostContent.GetPropertyAsJSObject("inputElement")
+ ?? throw new InvalidOperationException("InputElement cannot be null");
+
+ _splash = DomHelper.GetElementById("avalonia-splash");
+
+ _canvas.SetProperty("id", $"avaloniaCanvas{_canvasCount++}");
+
+ _topLevelImpl = new BrowserTopLevelImpl(this);
+
+ _topLevel = new WebEmbeddableControlRoot(_topLevelImpl, () =>
+ {
+ Dispatcher.UIThread.Post(() =>
+ {
+ if (_splash != null)
+ {
+ DomHelper.AddCssClass(_splash, "splash-close");
+ }
+ });
+ });
+
+ _topLevelImpl.SetCssCursor = (cursor) =>
+ {
+ InputHelper.SetCursor(_containerElement, cursor); // macOS
+ InputHelper.SetCursor(_canvas, cursor); // windows
+ };
+
+ _topLevel.Prepare();
+
+ _topLevel.Renderer.Start();
+
+ InputHelper.SubscribeKeyEvents(
+ _containerElement,
+ OnKeyDown,
+ OnKeyUp);
+
+ InputHelper.SubscribeTextEvents(
+ _inputElement,
+ OnTextInput,
+ OnCompositionStart,
+ OnCompositionUpdate,
+ OnCompositionEnd);
+
+ InputHelper.SubscribePointerEvents(_containerElement, OnPointerMove, OnPointerDown, OnPointerUp, OnWheel);
+
+ var skiaOptions = AvaloniaLocator.Current.GetService();
+
+ _dpi = DomHelper.ObserveDpi(OnDpiChanged);
+
+ _useGL = skiaOptions?.CustomGpuFactory != null;
+
+ if (_useGL)
+ {
+ _jsGlInfo = CanvasHelper.InitialiseGL(_canvas, OnRenderFrame);
+ // create the SkiaSharp context
+ if (_context == null)
+ {
+ _glInterface = GRGlInterface.Create();
+ _context = GRContext.CreateGl(_glInterface);
+
+ // bump the default resource cache limit
+ _context.SetResourceCacheLimit(skiaOptions?.MaxGpuResourceSizeBytes ?? 32 * 1024 * 1024);
+ }
+
+ _topLevelImpl.Surfaces = new[] { new BrowserSkiaSurface(_context, _jsGlInfo, ColorType, new PixelSize((int)_canvasSize.Width, (int)_canvasSize.Height), _dpi, GRSurfaceOrigin.BottomLeft) };
+ }
+ else
+ {
+ //var rasterInitialized = _interop.InitRaster();
+ //Console.WriteLine("raster initialized: {0}", rasterInitialized);
+
+ //_topLevelImpl.SetSurface(ColorType,
+ // new PixelSize((int)_canvasSize.Width, (int)_canvasSize.Height), _dpi, _interop.PutImageData);
+ }
+
+ CanvasHelper.SetCanvasSize(_canvas, (int)(_canvasSize.Width * _dpi), (int)(_canvasSize.Height * _dpi));
+
+ _topLevelImpl.SetClientSize(_canvasSize, _dpi);
+
+ DomHelper.ObserveSize(host, divId, OnSizeChanged);
+
+ CanvasHelper.RequestAnimationFrame(_canvas, true);
+ }
+
+ private static RawPointerPoint ExtractRawPointerFromJSArgs(JSObject args)
+ {
+ var point = new RawPointerPoint
+ {
+ Position = new Point(args.GetPropertyAsDouble("offsetX"), args.GetPropertyAsDouble("offsetY")),
+ Pressure = (float)args.GetPropertyAsDouble("pressure"),
+ XTilt = (float)args.GetPropertyAsDouble("tiltX"),
+ YTilt = (float)args.GetPropertyAsDouble("tiltY"),
+ Twist = (float)args.GetPropertyAsDouble("twist")
+ };
+
+ return point;
+ }
+
+ private bool OnPointerMove(JSObject args)
+ {
+ var type = args.GetPropertyAsString("pointertype");
+
+ var point = ExtractRawPointerFromJSArgs(args);
+
+ return _topLevelImpl.RawPointerEvent(RawPointerEventType.Move, type!, point, GetModifiers(args), args.GetPropertyAsInt32("pointerId"));
+ }
+
+ private bool OnPointerDown(JSObject args)
+ {
+ var pointerType = args.GetPropertyAsString("pointerType");
+
+ var type = pointerType switch
+ {
+ "touch" => RawPointerEventType.TouchBegin,
+ _ => args.GetPropertyAsInt32("button") switch
+ {
+ 0 => RawPointerEventType.LeftButtonDown,
+ 1 => RawPointerEventType.MiddleButtonDown,
+ 2 => RawPointerEventType.RightButtonDown,
+ 3 => RawPointerEventType.XButton1Down,
+ 4 => RawPointerEventType.XButton2Down,
+ // 5 => Pen eraser button,
+ _ => RawPointerEventType.Move
+ }
+ };
+
+ var point = ExtractRawPointerFromJSArgs(args);
+
+ return _topLevelImpl.RawPointerEvent(type, pointerType!, point, GetModifiers(args), args.GetPropertyAsInt32("pointerId"));
+ }
+
+ private bool OnPointerUp(JSObject args)
+ {
+ var pointerType = args.GetPropertyAsString("pointerType") ?? "mouse";
+
+ var type = pointerType switch
+ {
+ "touch" => RawPointerEventType.TouchEnd,
+ _ => args.GetPropertyAsInt32("button") switch
+ {
+ 0 => RawPointerEventType.LeftButtonUp,
+ 1 => RawPointerEventType.MiddleButtonUp,
+ 2 => RawPointerEventType.RightButtonUp,
+ 3 => RawPointerEventType.XButton1Up,
+ 4 => RawPointerEventType.XButton2Up,
+ // 5 => Pen eraser button,
+ _ => RawPointerEventType.Move
+ }
+ };
+
+ var point = ExtractRawPointerFromJSArgs(args);
+
+ return _topLevelImpl.RawPointerEvent(type, pointerType, point, GetModifiers(args), args.GetPropertyAsInt32("pointerId"));
+ }
+
+ private bool OnWheel(JSObject args)
+ {
+ return _topLevelImpl.RawMouseWheelEvent(new Point(args.GetPropertyAsDouble("clientX"), args.GetPropertyAsDouble("clientY")),
+ new Vector(-(args.GetPropertyAsDouble("deltaX") / 50), -(args.GetPropertyAsDouble("deltaY") / 50)), GetModifiers(args));
+ }
+
+ private static RawInputModifiers GetModifiers(JSObject e)
+ {
+ var modifiers = RawInputModifiers.None;
+
+ if (e.GetPropertyAsBoolean("ctrlKey"))
+ modifiers |= RawInputModifiers.Control;
+ if (e.GetPropertyAsBoolean("altKey"))
+ modifiers |= RawInputModifiers.Alt;
+ if (e.GetPropertyAsBoolean("shiftKey"))
+ modifiers |= RawInputModifiers.Shift;
+ if (e.GetPropertyAsBoolean("metaKey"))
+ modifiers |= RawInputModifiers.Meta;
+
+ var buttons = e.GetPropertyAsInt32("buttons");
+ if ((buttons & 1L) == 1)
+ modifiers |= RawInputModifiers.LeftMouseButton;
+
+ if ((buttons & 2L) == 2)
+ modifiers |= e.GetPropertyAsString("type") == "pen" ? RawInputModifiers.PenBarrelButton : RawInputModifiers.RightMouseButton;
+
+ if ((buttons & 4L) == 4)
+ modifiers |= RawInputModifiers.MiddleMouseButton;
+
+ if ((buttons & 8L) == 8)
+ modifiers |= RawInputModifiers.XButton1MouseButton;
+
+ if ((buttons & 16L) == 16)
+ modifiers |= RawInputModifiers.XButton2MouseButton;
+
+ if ((buttons & 32L) == 32)
+ modifiers |= RawInputModifiers.PenEraser;
+
+ return modifiers;
+ }
+
+ private bool OnKeyDown (string code, string key, int modifier)
+ {
+ return _topLevelImpl.RawKeyboardEvent(RawKeyEventType.KeyDown, code, key, (RawInputModifiers)modifier);
+ }
+
+ private bool OnKeyUp(string code, string key, int modifier)
+ {
+ return _topLevelImpl.RawKeyboardEvent(RawKeyEventType.KeyUp, code, key, (RawInputModifiers)modifier);
+ }
+
+ private bool OnTextInput (string type, string? data)
+ {
+ if(data == null || IsComposing)
+ {
+ return false;
+ }
+
+ return _topLevelImpl.RawTextEvent(data);
+ }
+
+ private bool OnCompositionStart (JSObject args)
+ {
+ if (_client == null)
+ return false;
+
+ _client.SetPreeditText(null);
+ IsComposing = true;
+
+ return false;
+ }
+
+ private bool OnCompositionUpdate(JSObject args)
+ {
+ if (_client == null)
+ return false;
+
+ _client.SetPreeditText(args.GetPropertyAsString("data"));
+
+ return false;
+ }
+
+ private bool OnCompositionEnd(JSObject args)
+ {
+ if (_client == null)
+ return false;
+
+ IsComposing = false;
+ _client.SetPreeditText(null);
+ _topLevelImpl.RawTextEvent(args.GetPropertyAsString("data")!);
+
+ return false;
+ }
+
+ private void OnRenderFrame()
+ {
+ if (_useGL && (_jsGlInfo == null))
+ {
+ Console.WriteLine("nothing to render");
+ return;
+ }
+ if (_canvasSize.Width <= 0 || _canvasSize.Height <= 0 || _dpi <= 0)
+ {
+ Console.WriteLine("nothing to render");
+ return;
+ }
+
+ ManualTriggerRenderTimer.Instance.RaiseTick();
+ }
+
+ public Control? Content
+ {
+ get => (Control)_topLevel.Content!;
+ set => _topLevel.Content = value;
+ }
+
+ public bool IsComposing { get; private set; }
+
+ internal INativeControlHostImpl GetNativeControlHostImpl()
+ {
+ return new BrowserNativeControlHost(_nativeControlsContainer);
+ }
+
+ private void ForceBlit()
+ {
+ // Note: this is technically a hack, but it's a kinda unique use case when
+ // we want to blit the previous frame
+ // renderer doesn't have much control over the render target
+ // we render on the UI thread
+ // We also don't want to have it as a meaningful public API.
+ // Therefore we have InternalsVisibleTo hack here.
+
+ if (_topLevel.Renderer is CompositingRenderer dr)
+ {
+ dr.CompositionTarget.ImmediateUIThreadRender();
+ }
+ }
+
+ private void OnDpiChanged(double oldDpi, double newDpi)
+ {
+ if (Math.Abs(_dpi - newDpi) > 0.0001)
+ {
+ _dpi = newDpi;
+
+ CanvasHelper.SetCanvasSize(_canvas, (int)(_canvasSize.Width * _dpi), (int)(_canvasSize.Height * _dpi));
+
+ _topLevelImpl.SetClientSize(_canvasSize, _dpi);
+
+ ForceBlit();
+ }
+ }
+
+ private void OnSizeChanged(int height, int width)
+ {
+ var newSize = new Size(height, width);
+
+ if (_canvasSize != newSize)
+ {
+ _canvasSize = newSize;
+
+ CanvasHelper.SetCanvasSize(_canvas, (int)(_canvasSize.Width * _dpi), (int)(_canvasSize.Height * _dpi));
+
+ _topLevelImpl.SetClientSize(_canvasSize, _dpi);
+
+ ForceBlit();
+ }
+ }
+
+ private void HideIme()
+ {
+ InputHelper.HideElement(_inputElement);
+ InputHelper.FocusElement(_containerElement);
+ }
+
+ public void SetClient(ITextInputMethodClient? client)
+ {
+ Console.WriteLine("Set Client");
+ if (_client != null)
+ {
+ _client.SurroundingTextChanged -= SurroundingTextChanged;
+ }
+
+ if (client != null)
+ {
+ client.SurroundingTextChanged += SurroundingTextChanged;
+ }
+
+ InputHelper.ClearInputElement(_inputElement);
+
+ _client = client;
+
+ if (_client != null)
+ {
+ InputHelper.ShowElement(_inputElement);
+ InputHelper.FocusElement(_inputElement);
+
+ var surroundingText = _client.SurroundingText;
+
+ InputHelper.SetSurroundingText(_inputElement, surroundingText.Text, surroundingText.AnchorOffset, surroundingText.CursorOffset);
+
+ Console.WriteLine("Shown, focused and surrounded.");
+ }
+ else
+ {
+ HideIme();
+ }
+ }
+
+ private void SurroundingTextChanged(object? sender, EventArgs e)
+ {
+ if (_client != null)
+ {
+ var surroundingText = _client.SurroundingText;
+
+ InputHelper.SetSurroundingText(_inputElement, surroundingText.Text, surroundingText.AnchorOffset, surroundingText.CursorOffset);
+ }
+ }
+
+ public void SetCursorRect(Rect rect)
+ {
+ InputHelper.FocusElement(_inputElement);
+ InputHelper.SetBounds(_inputElement, (int)rect.X, (int)rect.Y, (int)rect.Width, (int)rect.Height, _client?.SurroundingText.CursorOffset ?? 0);
+ InputHelper.FocusElement(_inputElement);
+ }
+
+ public void SetOptions(TextInputOptions options)
+ {
+ }
+
+ public void Reset()
+ {
+ InputHelper.ClearInputElement(_inputElement);
+ InputHelper.SetSurroundingText(_inputElement, "", 0, 0);
+ }
+ }
+}
diff --git a/src/Web/Avalonia.Web/BrowserNativeControlHost.cs b/src/Web/Avalonia.Web/BrowserNativeControlHost.cs
new file mode 100644
index 0000000000..4cdcf627e6
--- /dev/null
+++ b/src/Web/Avalonia.Web/BrowserNativeControlHost.cs
@@ -0,0 +1,136 @@
+using System;
+using System.Diagnostics.CodeAnalysis;
+using System.Runtime.InteropServices.JavaScript;
+
+using Avalonia.Controls.Platform;
+using Avalonia.Platform;
+using Avalonia.Web.Interop;
+
+namespace Avalonia.Web
+{
+ internal class BrowserNativeControlHost : INativeControlHostImpl
+ {
+ private readonly JSObject _hostElement;
+
+ public BrowserNativeControlHost(JSObject element)
+ {
+ _hostElement = element;
+ }
+
+ public INativeControlHostDestroyableControlHandle CreateDefaultChild(IPlatformHandle parent)
+ {
+ var element = NativeControlHostHelper.CreateDefaultChild(null);
+ return new JSObjectControlHandle(element);
+ }
+
+ public INativeControlHostControlTopLevelAttachment CreateNewAttachment(Func create)
+ {
+ Attachment? a = null;
+ try
+ {
+ var child = create(new JSObjectControlHandle(_hostElement));
+ var attachmenetReference = NativeControlHostHelper.CreateAttachment();
+ // It has to be assigned to the variable before property setter is called so we dispose it on exception
+#pragma warning disable IDE0017 // Simplify object initialization
+ a = new Attachment(attachmenetReference, child);
+#pragma warning restore IDE0017 // Simplify object initialization
+ a.AttachedTo = this;
+ return a;
+ }
+ catch
+ {
+ a?.Dispose();
+ throw;
+ }
+ }
+
+ public INativeControlHostControlTopLevelAttachment CreateNewAttachment(IPlatformHandle handle)
+ {
+ var attachmenetReference = NativeControlHostHelper.CreateAttachment();
+ var a = new Attachment(attachmenetReference, handle);
+ a.AttachedTo = this;
+ return a;
+ }
+
+ public bool IsCompatibleWith(IPlatformHandle handle) => handle is JSObjectControlHandle;
+
+ private class Attachment : INativeControlHostControlTopLevelAttachment
+ {
+ private const string InitializeWithChildHandleSymbol = "InitializeWithChildHandle";
+ private const string AttachToSymbol = "AttachTo";
+ private const string ShowInBoundsSymbol = "ShowInBounds";
+ private const string HideWithSizeSymbol = "HideWithSize";
+ private const string ReleaseChildSymbol = "ReleaseChild";
+
+ private JSObject? _native;
+ private BrowserNativeControlHost? _attachedTo;
+
+ public Attachment(JSObject native, IPlatformHandle handle)
+ {
+ _native = native;
+ NativeControlHostHelper.InitializeWithChildHandle(_native, ((JSObjectControlHandle)handle).Object);
+ }
+
+ public void Dispose()
+ {
+ if (_native != null)
+ {
+ NativeControlHostHelper.ReleaseChild(_native);
+ _native.Dispose();
+ _native = null;
+ }
+ }
+
+ public INativeControlHostImpl? AttachedTo
+ {
+ get => _attachedTo!;
+ set
+ {
+ CheckDisposed();
+
+ var host = (BrowserNativeControlHost?)value;
+ if (host == null)
+ {
+ NativeControlHostHelper.AttachTo(_native, null);
+ }
+ else
+ {
+ NativeControlHostHelper.AttachTo(_native, host._hostElement);
+ }
+ _attachedTo = host;
+ }
+ }
+
+ public bool IsCompatibleWith(INativeControlHostImpl host) => host is BrowserNativeControlHost;
+
+ public void HideWithSize(Size size)
+ {
+ CheckDisposed();
+ if (_attachedTo == null)
+ return;
+
+ NativeControlHostHelper.HideWithSize(_native, Math.Max(1, size.Width), Math.Max(1, size.Height));
+ }
+
+ public void ShowInBounds(Rect bounds)
+ {
+ CheckDisposed();
+
+ if (_attachedTo == null)
+ throw new InvalidOperationException("Native control isn't attached to a toplevel");
+
+ bounds = new Rect(bounds.X, bounds.Y, Math.Max(1, bounds.Width),
+ Math.Max(1, bounds.Height));
+
+ NativeControlHostHelper.ShowInBounds(_native, bounds.X, bounds.Y, bounds.Width, bounds.Height);
+ }
+
+ [MemberNotNull(nameof(_native))]
+ private void CheckDisposed()
+ {
+ if (_native == null)
+ throw new ObjectDisposedException(nameof(Attachment));
+ }
+ }
+ }
+}
diff --git a/src/Web/Avalonia.Web/BrowserSingleViewLifetime.cs b/src/Web/Avalonia.Web/BrowserSingleViewLifetime.cs
new file mode 100644
index 0000000000..091ab3f68c
--- /dev/null
+++ b/src/Web/Avalonia.Web/BrowserSingleViewLifetime.cs
@@ -0,0 +1,41 @@
+using System.Runtime.InteropServices.JavaScript;
+using System;
+using Avalonia.Controls;
+using Avalonia.Controls.ApplicationLifetimes;
+using Avalonia.Media;
+using Avalonia.Web.Skia;
+
+namespace Avalonia.Web
+{
+ [System.Runtime.Versioning.SupportedOSPlatform("browser")] // gets rid of callsite warnings
+ public class BrowserSingleViewLifetime : ISingleViewApplicationLifetime
+ {
+ public AvaloniaView? View;
+
+ public Control? MainView
+ {
+ get => View!.Content;
+ set => View!.Content = value;
+ }
+ }
+
+ public static partial class WebAppBuilder
+ {
+ public static T SetupBrowserApp(
+ this T builder, string mainDivId)
+ where T : AppBuilderBase, new()
+ {
+ var lifetime = new BrowserSingleViewLifetime();
+
+ return builder
+ .UseWindowingSubsystem(BrowserWindowingPlatform.Register)
+ .UseSkia()
+ .With(new SkiaOptions { CustomGpuFactory = () => new BrowserSkiaGpu() })
+ .AfterSetup(b =>
+ {
+ lifetime.View = new AvaloniaView(mainDivId);
+ })
+ .SetupWithLifetime(lifetime);
+ }
+ }
+}
diff --git a/src/Web/Avalonia.Web/BrowserTopLevelImpl.cs b/src/Web/Avalonia.Web/BrowserTopLevelImpl.cs
new file mode 100644
index 0000000000..b955da6df2
--- /dev/null
+++ b/src/Web/Avalonia.Web/BrowserTopLevelImpl.cs
@@ -0,0 +1,226 @@
+using System;
+using System.Collections.Generic;
+using System.Diagnostics;
+using System.Linq;
+using Avalonia.Controls;
+using Avalonia.Controls.Platform;
+using Avalonia.Input;
+using Avalonia.Input.Raw;
+using Avalonia.Input.TextInput;
+using Avalonia.Platform;
+using Avalonia.Platform.Storage;
+using Avalonia.Rendering;
+using Avalonia.Rendering.Composition;
+using Avalonia.Web.Skia;
+using Avalonia.Web.Storage;
+
+namespace Avalonia.Web
+{
+ [System.Runtime.Versioning.SupportedOSPlatform("browser")] // gets rid of callsite warnings
+ internal class BrowserTopLevelImpl : ITopLevelImplWithTextInputMethod, ITopLevelImplWithNativeControlHost, ITopLevelImplWithStorageProvider
+ {
+ private Size _clientSize;
+ private IInputRoot? _inputRoot;
+ private readonly Stopwatch _sw = Stopwatch.StartNew();
+ private readonly AvaloniaView _avaloniaView;
+ private readonly TouchDevice _touchDevice;
+ private readonly PenDevice _penDevice;
+ private string _currentCursor = CssCursor.Default;
+
+ public BrowserTopLevelImpl(AvaloniaView avaloniaView)
+ {
+ Surfaces = Enumerable.Empty
diff --git a/src/Avalonia.Base/Logging/LogArea.cs b/src/Avalonia.Base/Logging/LogArea.cs
index 98ef6d2530..972a9a1e9d 100644
--- a/src/Avalonia.Base/Logging/LogArea.cs
+++ b/src/Avalonia.Base/Logging/LogArea.cs
@@ -8,51 +8,66 @@ namespace Avalonia.Logging
///
/// The log event comes from the property system.
///
- public const string Property = "Property";
+ public const string Property = nameof(Property);
///
/// The log event comes from the binding system.
///
- public const string Binding = "Binding";
+ public const string Binding = nameof(Binding);
///
/// The log event comes from the animations system.
///
- public const string Animations = "Animations";
+ public const string Animations = nameof(Animations);
///
/// The log event comes from the visual system.
///
- public const string Visual = "Visual";
+ public const string Visual = nameof(Visual);
///
/// The log event comes from the layout system.
///
- public const string Layout = "Layout";
+ public const string Layout = nameof(Layout);
///
/// The log event comes from the control system.
///
- public const string Control = "Control";
+ public const string Control = nameof(Control);
///
- /// The log event comes from Win32Platform.
+ /// The log event comes from Win32 Platform.
///
public const string Win32Platform = nameof(Win32Platform);
///
- /// The log event comes from X11Platform.
+ /// The log event comes from X11 Platform.
///
public const string X11Platform = nameof(X11Platform);
///
- /// The log event comes from AndroidPlatform.
+ /// The log event comes from Android Platform.
///
public const string AndroidPlatform = nameof(AndroidPlatform);
///
/// The log event comes from IOSPlatform.
///
public const string IOSPlatform = nameof(IOSPlatform);
+
+ ///
+ /// The log event comes from LinuxFramebuffer Platform
+ ///
+ public const string LinuxFramebufferPlatform = nameof(LinuxFramebufferPlatform);
+
+ ///
+ /// The log event comes from FreeDesktop Platform
+ ///
+ public const string FreeDesktopPlatform = nameof(FreeDesktopPlatform);
+
+ ///
+ /// The log event comes from macOS Platform
+ ///
+ public const string macOSPlatform = nameof(macOSPlatform);
}
}
@@ -8,51 +8,66 @@ namespace Avalonia.Logging
public const string AndroidPlatform = nameof(AndroidPlatform);
///
- /// The log event comes from IOSPlatform.
+ /// The log event comes from iOS Platform.
///
public const string IOSPlatform = nameof(IOSPlatform);